import { Analytics, EventParams, AnalyticsCallOptions, CustomParams } from "firebase/analytics";
import { QueryKey, UseMutationOptions, UseMutationResult, UseQueryOptions, UseQueryResult } from "react-query";
export declare function useAnalyticsIsSupported(key: QueryKey, useQueryOptions?: UseQueryOptions<boolean, Error>): UseQueryResult<boolean, Error>;
export declare function useAnalyticsSetCollectionEnabled(analytics: Analytics, useMutationOptions?: UseMutationOptions<void, Error, boolean>): UseMutationResult<void, Error, boolean>;
export declare function useAnalyticsSetCurrentScreen(analytics: Analytics, useMutationOptions?: UseMutationOptions<void, Error, {
    screenName: string;
    options?: AnalyticsCallOptions;
}>): UseMutationResult<void, Error, {
    screenName: string;
    options?: AnalyticsCallOptions;
}>;
export declare function useAnalyticsSetUserId(analytics: Analytics, useMutationOptions?: UseMutationOptions<void, Error, {
    id: string;
    options?: AnalyticsCallOptions;
}>): UseMutationResult<void, Error, {
    id: string;
    options?: AnalyticsCallOptions;
}>;
export declare function useAnalyticsSetUserProperties(analytics: Analytics, useMutationOptions?: UseMutationOptions<void, Error, {
    properties: CustomParams;
    options?: AnalyticsCallOptions;
}>): UseMutationResult<void, Error, {
    properties: CustomParams;
    options?: AnalyticsCallOptions;
}>;
declare type LogEventArgs<K extends keyof AnalyticsEventMap> = {
    params?: AnalyticsEventMap[K];
    options?: AnalyticsCallOptions;
};
export declare function useAnalyticsLogEvent(analytics: Analytics, eventName: keyof AnalyticsEventMap, useMutationOptions?: UseMutationOptions<void, Error, void | LogEventArgs<typeof eventName>>): UseMutationResult<void, Error, void | LogEventArgs<typeof eventName>>;
declare type CustomLogArgs = {
    params?: {
        [key: string]: any;
    };
    options?: AnalyticsCallOptions;
};
export declare function useAnalyticsCustomLogEvent(analytics: Analytics, eventName: string, useMutationOptions?: UseMutationOptions<void, Error, void | CustomLogArgs>): UseMutationResult<void, Error, void | CustomLogArgs>;
export declare type AnalyticsEventMap = {
    add_payment_info: AnalyticsPaymentInfo;
    purchase: AnalyticsPurchaseOrRefund;
    refund: AnalyticsPurchaseOrRefund;
    screen_view: AnalyticsScreenView;
    search: AnalyticsSearchOrViewSearchResults;
    view_search_results: AnalyticsSearchOrViewSearchResults;
    select_content: AnalyticsSelectContent;
    select_item: AnalyticsSelectItem;
    select_promotion: AnalyticsPromotion;
    view_promotion: AnalyticsPromotion;
    set_checkout_option: AnalyticsSetCheckoutOption;
    share: AnalyticsShare;
    sign_up: AnalyticsSignUp;
    timing_complete: AnalyticsTimingComplete;
    add_shipping_info: AnalyticsAddShippingInfo;
    view_cart: AnalyticsViewCartItem;
    view_item: AnalyticsViewCartItem;
    view_item_list: AnalyticsViewItemList;
};
export declare type AnalyticsPaymentInfo = {
    coupon?: EventParams["coupon"];
    currency?: EventParams["currency"];
    items?: EventParams["items"];
    payment_type?: EventParams["payment_type"];
    value?: EventParams["value"];
    [key: string]: any;
};
export declare type AnalyticsPurchaseOrRefund = {
    value?: EventParams["value"];
    currency?: EventParams["currency"];
    transaction_id: EventParams["transaction_id"];
    tax?: EventParams["tax"];
    shipping?: EventParams["shipping"];
    items?: EventParams["items"];
    coupon?: EventParams["coupon"];
    affiliation?: EventParams["affiliation"];
    [key: string]: any;
};
export declare type AnalyticsScreenView = {
    firebase_screen: EventParams["firebase_screen"];
    firebase_screen_class: EventParams["firebase_screen_class"];
    [key: string]: any;
};
export declare type AnalyticsSearchOrViewSearchResults = {
    search_term?: EventParams["search_term"];
    [key: string]: any;
};
export declare type AnalyticsSelectContent = {
    content_type?: EventParams["content_type"];
    item_id?: EventParams["item_id"];
    [key: string]: any;
};
export declare type AnalyticsSelectItem = {
    items?: EventParams["items"];
    item_list_name?: EventParams["item_list_name"];
    item_list_id?: EventParams["item_list_id"];
    [key: string]: any;
};
export declare type AnalyticsPromotion = {
    items?: EventParams["items"];
    promotion_id?: EventParams["promotion_id"];
    promotion_name?: EventParams["promotion_name"];
    [key: string]: any;
};
export declare type AnalyticsSetCheckoutOption = {
    checkout_step?: EventParams["checkout_step"];
    checkout_option?: EventParams["checkout_option"];
    [key: string]: any;
};
export declare type AnalyticsShare = {
    method?: EventParams["method"];
    content_type?: EventParams["content_type"];
    item_id?: EventParams["item_id"];
    [key: string]: any;
};
export declare type AnalyticsSignUp = {
    method?: EventParams["method"];
    [key: string]: any;
};
export declare type AnalyticsTimingComplete = {
    method?: EventParams["method"];
    [key: string]: any;
};
export declare type AnalyticsAddShippingInfo = {
    coupon?: EventParams["coupon"];
    currency?: EventParams["currency"];
    items?: EventParams["items"];
    shipping_tier?: EventParams["shipping_tier"];
    value?: EventParams["value"];
    [key: string]: any;
};
export declare type AnalyticsViewCartItem = {
    currency?: EventParams["currency"];
    items?: EventParams["items"];
    value?: EventParams["value"];
    [key: string]: any;
};
export declare type AnalyticsViewItemList = {
    items?: EventParams["items"];
    item_list_name?: EventParams["item_list_name"];
    item_list_id?: EventParams["item_list_id"];
    [key: string]: any;
};
export {};
